aboutsummaryrefslogtreecommitdiff
path: root/payloads/libpayload/drivers/cmos.c
diff options
context:
space:
mode:
Diffstat (limited to 'payloads/libpayload/drivers/cmos.c')
-rw-r--r--payloads/libpayload/drivers/cmos.c16
1 files changed, 8 insertions, 8 deletions
diff --git a/payloads/libpayload/drivers/cmos.c b/payloads/libpayload/drivers/cmos.c
index c8cd605a0a..3789c09b3c 100644
--- a/payloads/libpayload/drivers/cmos.c
+++ b/payloads/libpayload/drivers/cmos.c
@@ -45,24 +45,24 @@
#define RTC_PORT 0x70
/**
* Read a byte from the specified CMOS address.
*
* @param addr The CMOS address to read a byte from.
* @return The byte at the given CMOS address.
*/
-u8 cmos_read(u8 addr)
+u8 nvram_read(u8 addr)
{
outb(addr, RTC_PORT);
return inb(RTC_PORT + 1);
}
/**
* Write a byte to the specified CMOS address.
*
* @param val The byte to write to CMOS.
* @param addr The CMOS address to write to.
*/
-void cmos_write(u8 val, u8 addr)
+void nvram_write(u8 val, u8 addr)
{
outb(addr, RTC_PORT);
outb(val, RTC_PORT + 1);
@@ -45,24 +45,24 @@
#define RTC_PORT 0x70
/**
- * Read a byte from the specified CMOS address.
+ * Read a byte from the specified NVRAM address.
*
@@ -45,24 +45,24 @@
*
- * @param addr The CMOS address to read a byte from.
- * @return The byte at the given CMOS address.
+ * @param addr The NVRAM address to read a byte from.
+ * @return The byte at the given NVRAM address.
*/
@@ -45,24 +45,24 @@
}
/**
- * Write a byte to the specified CMOS address.
+ * Write a byte to the specified NVRAM address.
*
@@ -45,24 +45,24 @@
*
- * @param val The byte to write to CMOS.
- * @param addr The CMOS address to write to.
+ * @param val The byte to write to NVRAM.
+ * @param addr The NVRAM address to write to.
*/